****************************************************************************
****************************************************************************
**                                                                        **
**   Phoenix for TI-89, TI-92, and TI-92 Plus : Player's Bullet Routines  **
**                                                                        **
**   Copyright 1997-2000 by Patrick Davidson.  All Rights Reserved.       **
**                                                                        **
**   This file was last updated May 5, 2000                               **
**                                                                        **
**   For complete copyright information and contact addresses, refer to   **
**   the main source file "PHOENIX.ASM"                                   **
**                                                                        **
****************************************************************************
****************************************************************************

******************************************** DRAW/ERASE PLAYER'S BULLETS
*
* XOR each of the player's bullets with the screen with the standard
* sprite display routine.  The exception is the special weapon, which is
* identified by its negative type number; for this weapon, the special
* drawing routine is called, which simply fills in the entire block of the
* screen that the shot occupies (it's always on a byte boundary).
*
********

Player_Bullets_Draw:
         lea      bullets_data(a5),a4        
         move.w   num_b(a5),d7
loop_draw_player_bullets:
         tst.w    (a4)
         beq.s    pbd_no_bullet_here
         ble.s    special_bullet
         move.w   b_x(a4),d0
         move.w   b_y(a4),d1
         move.w   b_image(a4),d2
         bsr      Xor_Sprite_D2
pbd_no_bullet_here:
         lea      b_size(a4),a4
         dbra     d7,loop_draw_player_bullets
         rts

special_bullet:
         move.w   b_y(a4),d0
         lsl.w    #5,d0
         move.w   b_x(a4),d1
         lsr.w    #3,d1
         add.w    d1,d0
         lea      0(a5,d0.w),a1
         lea      32(a1),a2
         lea      32(a2),a3
         move.w   b_w(a4),d0
         lsr.w    #3,d0
loop_sdraw:
         st       (a1)+
         st       (a2)+
         st       (a3)+
         dbra     d0,loop_sdraw
         bra.s    pbd_no_bullet_here

******************************************** MOVE SPECIAL BULLET
*
* This is the code for moving the special bullet, fired by ship II's special
* weapon.  It is unique in that it won't be destroyed when it hits an enemy;
* to be special, it must have a negative type, thus it needs to be before
* the base of the offsets (while all other bullets must be after).
*
********

bx_special:
         subq.w   #1,b_data(a4)
         beq      bx_kill
         move.w   b_x(a4),d0
         beq.s    bxs_l
         subq.w   #8,d0
         move.w   d0,b_x(a4)
bxs_l:   addq.w   #8,b_w(a4)
         add.w    b_w(a4),d0
         cmp.w    #256,d0
         beq.s    bxs_r
         addq.w   #8,b_w(a4)
bxs_r:   subq.w   #3,b_y(a4)
         rts

******************************************** MOVE PLAYER'S BULLETS
*
* For each of the player's bullets, calls the bullet routine for that bullet
* type, located by the table of bullet routines found below.  Routine is
* called with A4 pointing to the start of the bullet structure.  The routine
* must preserve the A4 and D7 registers.  The purpose of the bullter routine
* is to update the bullet's coordinates and image, and remove it if
* necessary.  It should not draw the bullet image to the screen.
*
********

Player_Bullets_Move:
         lea      bullets_data(a5),a4
         move.w   num_b(a5),d7
loop_move_bullets:
         move.w   (a4),d0
         beq.s    pbm_no_bullet_here
         jsr      Player_Bullets_Move(pc,d0.w)
pbm_no_bullet_here:
         lea      b_size(a4),a4
         dbra     d7,loop_move_bullets
         rts

********************************************** BULLET MOVING CODE

bx_Ultimate4:
         moveq    #4,d1
         bra.s    bx_Ultimate
bx_Ultimate3:
         moveq    #1,d1
         bra.s    bx_Ultimate
bx_Ultimate2:
         moveq    #-1,d1
         bra.s    bx_Ultimate
bx_Ultimate1:
         moveq    #-4,d1
bx_Ultimate:
         addq.w   #1,b_data(a4)
         move.w   b_data(a4),d2
         and.w    #6,d2
         bne.s    nomove
         add.w    d1,b_x(a4)
         ble.s    bx_kill
         cmp.w    #240,b_x(a4)
         bge.s    bx_kill
nomove:  sub.w    #9,b_y(a4)
         blt.s    bx_kill
         rts

bx_GA_Right:
         addq.w   #1,b_x(a4)
         cmp.w    #240,b_x(a4)
         bge      bx_kill
         subq.w   #1,b_data(a4)
         move.w   b_data(a4),d0
         asr.w    #1,d0
         add.w    d0,b_y(a4)
         ble.s    bx_kill
         rts
bx_GA_Left:
         subq.w   #1,b_x(a4)
         ble.s    bx_kill
         subq.w   #1,b_data(a4)
         move.w   b_data(a4),d0
         asr.w    #1,d0
         add.w    d0,b_y(a4)
         ble.s    bx_kill
         rts

bx_quad_up:
         subq.w   #7,b_y(a4)
         blt      bx_kill
         rts

bx_Swing_Right:
         addq.w   #1,b_data(a4)
         btst     #2,b_data+1(a4)
         beq.s    bx_quad_up
         subq.w   #6,b_y(a4)
         blt.s    bx_kill
         addq.w   #4,b_x(a4)
         cmp.w    #240,b_x(a4)
         bge.s    bx_kill         
         rts

bx_kill:
         clr.w    (a4)
         rts

bx_Swing_Left:
         addq.w   #1,b_data(a4)
         btst     #2,b_data+1(a4)
         beq.s    bx_quad_up
         subq.w   #6,b_y(a4)
         blt.s    bx_kill
         subq.w   #4,b_x(a4)
         blt.s    bx_kill         
         rts

bx_fast_bullet:
         move.w   b_x(a4),d0
         add.w    b_data(a4),d0
         cmp.w    #13,d0
         blt.s    bx_kill
         cmp.w    #240,d0
         bge.s    bx_kill
         move.w   d0,b_x(a4)
         subq.w   #6,b_y(a4)
         blt.s    bx_kill
         rts

bx_Triple_Left:
         subq.w   #3,b_x(a4)
         blt.s    bx_kill

bx_normal_bullet:
         subq.w   #4,b_y(a4)
         blt.s    bx_kill
         rts

bx_Triple_Right:
         addq.w   #3,b_x(a4)
         cmp.w    #240,b_x(a4)
         bgt.s    bx_kill
         subq.w   #4,b_y(a4)
         blt.s    bx_kill
         rts

bx_Triple_Forward:
         subq.w   #5,b_y(a4)
         blt.s    bx_kill
         rts

bx_huge: move.b   b_data+1(a4),d1
         ext.w    d1
         add.w    d1,b_y(a4)
         ble      bx_kill

         move.w   b_x(a4),d0
         move.b   b_data(a4),d1
         ext.w    d1
         add.w    d1,d0
         move.w   d0,b_x(a4)
         ble      bx_kill
         cmp.w    #240,d0
         bge      bx_kill
         rts

********************************************* BULLET TYPES
*
* The PBULLET macro assigns a bullet type to each bullet the player has.
* The first argument is the symbol that is created for the type, and the
* second is the bullet's code.  The bullet type is a relative pointer, and
* is used in the type field of the bullet array.
*
* As this table is only used to set symbols to equal the offsets, this table
* takes absolutely no space in the executable code.
*
********

PBULLET  MACRO
\1       equ      \2-Player_Bullets_Move
         ENDM

         PBULLET  PB_SPECIAL,bx_special
         PBULLET  PB_NORMAL,bx_normal_bullet
         PBULLET  PB_TRIPLE_FORWARD,bx_Triple_Forward
         PBULLET  PB_TRIPLE_LEFT,bx_Triple_Left
         PBULLET  PB_TRIPLE_RIGHT,bx_Triple_Right
         PBULLET  PB_SWING_LEFT,bx_Swing_Left
         PBULLET  PB_SWING_RIGHT,bx_Swing_Right
         PBULLET  PB_FAST,bx_fast_bullet
         PBULLET  PB_ARCH_LEFT,bx_GA_Left
         PBULLET  PB_ARCH_RIGHT,bx_GA_Right
         PBULLET  PB_HUGE,bx_huge
         PBULLET  PB_U1,bx_Ultimate1
         PBULLET  PB_U2,bx_Ultimate2
         PBULLET  PB_U3,bx_Ultimate3
         PBULLET  PB_U4,bx_Ultimate4
